# -*- coding: utf-8 -*-
# Generated by Django 1.11.15 on 2018-10-17 12:13
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_rest_passwordreset', '0004_resetpasswordtoken_expired'),
    ]

    operations = [
        migrations.AlterField(
            model_name='resetpasswordtoken',
            name='key',
            field=models.CharField(db_index=True, max_length=64, unique=True, verbose_name='Key'),
        ),
    ]
